// WctpClientReceive.hpp

#ifndef WCTPCLIENTRECEIVE_HPP
#define WCTPCLIENTRECEIVE_HPP

#include "WctpFactory.hpp"
#include <string>
#include <strstream>
#include <ctime>

using namespace std;

/* Class WctpClientReceive
 * Contains functionality to work with responses recieved from a WCTP gateway.
 * This is beta software that is still under development.  Use
 * at your own risk.
 *
 * New in this version:
 * - now accepts host names rather than just IP addresses
 *
 * Copyright 2000-2001 Arch Wireless Holdings, Inc.
 * Version 0.1 Beta August 8, 2001
 */
class WctpClientReceive : public WctpFactory {
public:

 /*
  * Constructor
  */
  WctpClientReceive();

 /*
  * Destructor
  */
  ~WctpClientReceive();

 /* Extracts an error or success code from a WCTP packet
  * and gives an appropriate message
  *
  * Parameters:
  * inputLine - an XML document generated by the WCTP gateway
  *
  * Returns the  the error/success code, or -1 if neither are found
  */
  int getResponseCode(string inputLine);

 /* Extracts a tracking code from a XML document
  * and gives an appropriate response message.
  * There is a known bug in this method
  * The tracking code is not read correctly
  *
  * Parameters:
  * inputLine - an XML document generated by the WCTP gateway
  *
  * Returns the tracking code, or null if it's not found
  */
  string getTrackingCode(string inputLine);

 /* Error and Success Code definitions
  *
  * Parameters:
  * wctpCode - the wctp code
  *
  * Returns the definition of the code
  */
  string findCode(int wctpCode);

private:

};

#endif
